@@ -83,16 +83,9 @@ export class MapWalker extends GObject.Object {
     zoomToFit() {
         let zoom = this._getZoomLevel();
 
-         /*
-         * WORKAROUND!!!!
-         *
-         * For now disable the animation to prevent getting
-         * throttled by the tile server:
-         * https://gitlab.gnome.org/GNOME/gnome-maps/-/issues/546
-         */
-        this._mapView.map.center_on(this.place.location.latitude,
-                                    this.place.location.longitude);
-        this._mapView.map.viewport.zoom_level = zoom;
+        this._mapView.map.go_to_full(this.place.location.latitude,
+                                     this.place.location.longitude,
+                                     zoom);
     }
 
     goTo(animate, linear) {
@@ -102,15 +95,6 @@ export class MapWalker extends GObject.Object {
                     this.place.location.longitude].join(' '));
         this._mapView.emit('going-to');
 
-        /*
-         * WORKAROUND!!!!
-         *
-         * For now disable the go-to animation to prevent getting
-         * throttled by the tile server:
-         * https://gitlab.gnome.org/GNOME/gnome-maps/-/issues/546
-         */
-        animate = false;
-
         if (!animate) {
             this._mapView.map.center_on(this.place.location.latitude,
                                         this.place.location.longitude);
