@@ -24,6 +24,7 @@ import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
 import Gtk from 'gi://Gtk';
 import Pango from 'gi://Pango';
+import Xdp from 'gi://Xdp';
 
 const Format = imports.format;
 
@@ -114,24 +115,26 @@ export class PlaceView extends Gtk.Box {
         } else {
             let overpass = new Overpass();
 
-            /* use a property binding from the Overpass instance to avoid
-             * accessing this object after the underlying GObject has
-             * been finalized */
-            overpass.bind_property('place', this, 'overpass-place',
-                                   GObject.BindingFlags.DEFAULT);
-            this.connect('notify::overpass-place', () => this._onInfoAdded());
-
             if (Application.placeStore.exists(this.place, null)) {
 
                 // If the place is stale, update from Overpass.
                 if (Application.placeStore.isStale(this.place)) {
-                    overpass.addInfo(this.place);
+                    overpass.populatePlace(this.place,
+                                           this._onOverpass.bind(this));
                 } else {
                     this._place = Application.placeStore.get(this.place);
                     this._populate(this.place);
                 }
-            } else if (this.place.store && !this.place.prefilled) {
-                overpass.addInfo(this.place);
+            } else if (this.place.store) {
+                /* if we got a place with already pre-filled data from
+                 * Overpass, make sure it is stored in the place store
+                 */
+                if (this.place.prefilled) {
+                    this._onOverpass(true);
+                } else {
+                    overpass.populatePlace(this.place,
+                                           this._onOverpass.bind(this));
+                }
             } else {
                 this._populate(this.place);
             }
@@ -155,12 +158,12 @@ export class PlaceView extends Gtk.Box {
     }
 
     get thumbnail() {
-        return this._thumbnail.pixbuf;
+        return this._thumbnail.paintable;
     }
 
     set thumbnail(val) {
         if (val) {
-            this._thumbnail.pixbuf = val;
+            this._thumbnail.paintable = val;
             this._thumbnail.visible = true;
             this._thumbnailSeparator.visible = true;
         }
@@ -215,8 +218,12 @@ export class PlaceView extends Gtk.Box {
         }
     }
 
-    _onInfoAdded() {
+    _onOverpass(success) {
+        if (!success)
+            return;
+
         this._populate(this.place);
+
         if (Application.placeStore.exists(this.place, null))
             Application.placeStore.updatePlace(this.place);
         else
@@ -269,7 +276,12 @@ export class PlaceView extends Gtk.Box {
                           icon: 'phone-oldschool-symbolic',
                           info: LRM + GLib.markup_escape_text(place.phone, -1) };
 
-            if (Utils.uriSchemeSupported('tel')) {
+            /* if we're running in a sandbox (Flatpak or Snap), assume
+             * we have some app that can handle tel: URIs, as we can't
+             * enumerate apps inside the sandbox
+             */
+            if (Xdp.Portal.running_under_sandbox() ||
+                Utils.uriSchemeSupported('tel')) {
                 /* RFC3966 only allows "-", '.", "(", and ")" as visual
                  * separator characters in a global phone number, no space */
                 phone.linkUrl = `tel:${place.phone.replace(/\s+/g, '')}`;
@@ -292,7 +304,7 @@ export class PlaceView extends Gtk.Box {
                      * The establishment offers customers to purchase meals
                      * (or similar) to be consumed elsewhere
                      */
-                    content.push({ info: _("Offers takeaway"),
+                    content.push({ info: _("Offers takeout"),
                                    icon: PlaceIcons.getIconForPlace(place) });
                     break;
                 case 'no':
@@ -300,7 +312,7 @@ export class PlaceView extends Gtk.Box {
                      * The establishment only offers customers to purchase
                      * meals (or similar) to be consumed on-premise.
                      */
-                    content.push({ info: _("Does not offer takeaway"),
+                    content.push({ info: _("Does not offer takeout"),
                                    icon: PlaceIcons.getIconForPlace(place) });
                     break;
                 case 'only':
@@ -309,7 +321,7 @@ export class PlaceView extends Gtk.Box {
                      * meals (or similar) to be consumed elsewhere. E.g.
                      * there is no seating on-premise for eating/drinking
                      */
-                    content.push({ info: _("Only offers takeaway"),
+                    content.push({ info: _("Only offers takeout"),
                                    icon: PlaceIcons.getIconForPlace(place) });
                     break;
             }
@@ -465,31 +477,34 @@ export class PlaceView extends Gtk.Box {
                            info: Translations.translateReligion(place.religion) });
         }
 
-        if (place.wiki && Wikipedia.isValidWikipedia(place.wiki) ||
-            place.wikidata && Wikipedia.isValidWikidata(place.wikidata)) {
-            content.push({ type: 'wikipedia', info: '' });
+        return content;
+    }
+
+    _addBox() {
+        let separator = new Gtk.Separator();
+
+        separator.get_style_context().add_class('no-margin-separator');
+        this._placeDetails.append(separator);
+
+        let box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
+                                marginStart: 12,
+                                marginEnd: 12,
+                                marginTop: 6,
+                                marginBottom: 6,
+                                spacing: 12 });
+
+        if (this._inlineMode) {
+            box.marginStart = 6;
         }
 
-        return content;
+        this._placeDetails.append(box);
+
+        return box;
     }
 
     _attachContent(content) {
         content.forEach(({ type, label, icon, linkUrl, info, grid }) => {
-            let separator = new Gtk.Separator({ visible: true });
-            separator.get_style_context().add_class('no-margin-separator');
-            this._placeDetails.append(separator);
-
-            let box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
-                                    visible: true,
-                                    marginStart: 12,
-                                    marginEnd: 12,
-                                    marginTop: 6,
-                                    marginBottom: 6,
-                                    spacing: 12 });
-
-            if (this._inlineMode) {
-                box.marginStart = 6;
-            }
+            let box = this._addBox();
 
             if (icon) {
                 let widget = new Gtk.Image({ icon_name: icon,
@@ -558,16 +573,9 @@ export class PlaceView extends Gtk.Box {
                                          xalign: 0,
                                          hexpand: true,
                                          halign: Gtk.Align.FILL });
-
-                if (type === 'wikipedia') {
-                    box.marginTop = 12;
-                    box.marginBottom = 18;
-                    this._wikipediaLabel = widget;
-                }
             }
 
             box.append(widget);
-            this._placeDetails.append(box);
         });
     }
 
@@ -612,6 +620,14 @@ export class PlaceView extends Gtk.Box {
 
     _onWikiMetadataComplete(wiki, metadata) {
         if (metadata.extract) {
+            let box = this._addBox();
+            let wikipediaLabel = new Gtk.Label({ use_markup: true,
+                                                 max_width_chars: 30,
+                                                 wrap: true,
+                                                 xalign: 0,
+                                                 hexpand: true,
+                                                 halign: Gtk.Align.FILL });
+
             let text = GLib.markup_escape_text(metadata.extract, -1);
             let link = this._formatWikiLink(wiki);
 
@@ -627,7 +643,12 @@ export class PlaceView extends Gtk.Box {
 
             /* Translators: This is the text for the "Wikipedia" link at the end
                of summaries */
-            this._wikipediaLabel.label = `${text} <a href="${uri}" title="${tooltipText}">${ _("Wikipedia") }</a>`;
+            let label = `${text} <a href="${uri}" title="${tooltipText}">${ _("Wikipedia") }</a>`;
+
+            wikipediaLabel.label = label;
+            box.marginTop = 12;
+            box.marginBottom = 18;
+            box.append(wikipediaLabel);
         }
     }
 
@@ -655,13 +676,4 @@ export class PlaceView extends Gtk.Box {
     }
 }
 
-GObject.registerClass({
-    Properties: {
-        'overpass-place': GObject.ParamSpec.object('overpass-place',
-                                                   'Overpass Place',
-                                                   'The place as filled in by Overpass',
-                                                   GObject.ParamFlags.READABLE |
-                                                   GObject.ParamFlags.WRITABLE,
-                                                   GeocodeGlib.Place)
-    }
-}, PlaceView);
+GObject.registerClass(PlaceView);
