@@ -28,6 +28,7 @@ import GdkPixbuf from 'gi://GdkPixbuf';
 import GeocodeGlib from 'gi://GeocodeGlib';
 import Gio from 'gi://Gio';
 import Gtk from 'gi://Gtk';
+import Adw from 'gi://Adw';
 import GWeather from 'gi://GWeather';
 
 const _ = gettext.gettext;
@@ -262,22 +263,6 @@ export function getAccuracyDescription(accuracy) {
     }
 }
 
-export function loadAvatar(pixbuf, size) {
-    let width = pixbuf.get_width();
-    let height = pixbuf.get_height();
-    let croppedThumbnail;
-
-    if (width > height) {
-        let x = (width - height) / 2;
-        croppedThumbnail = pixbuf.new_subpixbuf(x, 0, height, height);
-    } else {
-        let y = (height - width) / 2;
-        croppedThumbnail = pixbuf.new_subpixbuf(0, y, width, width);
-    }
-
-    return croppedThumbnail.scale_simple(size, size, GdkPixbuf.InterpType.BILINEAR);
-}
-
 export function load_icon(icon, size, loadCompleteCallback) {
     if (icon instanceof Gio.FileIcon || icon instanceof Gio.BytesIcon) {
         _load_icon(icon, loadCompleteCallback);
@@ -453,17 +438,12 @@ export function isUsingHighContrastTheme() {
     return themeName === 'HighContrast' || themeName === 'HighContrastInverse';
 }
 
-export function showDialog(msg, type, transientFor) {
-    let messageDialog =
-        new Gtk.MessageDialog({ transient_for: transientFor,
-                                destroy_with_parent: true,
-                                message_type: type,
-                                buttons: Gtk.ButtonsType.OK,
-                                modal: true,
-                                text: msg });
+export function showToastInOverlay(message, overlay) {
+    let toast = new Adw.Toast({
+        title: message,
+    });
 
-    messageDialog.connect('response', () => messageDialog.destroy());
-    messageDialog.show();
+    overlay.add_toast(toast);
 }
 
 let decoder = new TextDecoder('utf-8');
